@@ -41,6 +41,14 @@ class GSPeerConnectionBroadcaster:
                 relay = MediaRelay()
             return None, relay.subscribe(webcam.video)
 
+    def force_codec(self, pc, sender, forced_codec):
+        kind = forced_codec.split("/")[0]
+        codecs = RTCRtpSender.getCapabilities(kind).codecs
+        transceiver = next(t for t in pc.getTransceivers() if t.sender == sender)
+        transceiver.setCodecPreferences(
+            [codec for codec in codecs if codec.mimeType == forced_codec]
+        )
+
     @classmethod
     async def create(cls, gsdbs):
         self = GSPeerConnectionBroadcaster()
@@ -70,26 +78,20 @@ class GSPeerConnectionBroadcaster:
                              self.gsdbs.credentials["turnuser"],
                              self.gsdbs.credentials["turnpw"]),
             ]))
+
             self.peerConnections[id] = pc
 
             audio, video = self.create_local_tracks_new(
-                None, decode=self.gsdbs.credentials["decode"]
+                None, decode=not self.gsdbs.credentials["decode"]
             )
+
             video_codec = self.gsdbs.credentials["videocodec"]
 
-            if audio:
-                pc.addTrack(audio)
             if video:
                 video_sender = pc.addTrack(video)
                 if video_codec:
-                    # only allow the specified video codec
-                    video_codecs = RTCRtpSender.getCapabilities("video").codecs
-                    video_transceiver = next(
-                        t for t in pc.getTransceivers() if t.sender == video_sender
-                    )
-                    video_transceiver.setCodecPreferences(
-                        [codec for codec in video_codecs if codec.mimeType == video_codec]
-                    )
+                    self.force_codec(pc, video_sender, video_codec)
+
 
             @pc.on("iceconnectionstatechange")
             async def on_iceconnectionstatechange():
@@ -101,8 +103,9 @@ class GSPeerConnectionBroadcaster:
             await pc.setLocalDescription(await pc.createOffer())
             await self.sio.emit("offer", {"id": id,
                                           "message": json.dumps(
-                                              {"type": pc.localDescription.type, "sdp": pc.localDescription.sdp})})
-            # self._logger.info(pc.signalingState)
+                                              {"type": pc.localDescription.type,
+                                               "sdp": pc.localDescription.sdp})})
+
 
         @self.sio.event
         async def disconnectPeer(id):
